from __future__ import annotations

from prettyqt import widgets
from prettyqt.qt import QtSvg


class GraphicsSvgItem(widgets.GraphicsObjectMixin, QtSvg.QGraphicsSvgItem):
    pass
